@@ -8,6 +8,7 @@ from ....config import TENSHI
 from ...helper import construct_site_based_regex, uwu
 
 REGEX = construct_site_based_regex(TENSHI, extra_regex=r"/anime/([^?&/]+)")
+TITLES_REGEX = regex.compile(r'<h1 class="mb-3">(.+?)</h1>')
 
 
 def post_processor(session, stream_page):
@@ -56,3 +57,11 @@ def fetcher(
                 lambda c: [*extract_urls(session, c, post_processor=post_processor)],
                 "{}/{:d}".format(url, episode),
             ), episode
+
+
+def metadata_fetcher(session, url, match, *, domain=TENSHI):
+
+    uwu.bypass_ddos_guard(session, domain)
+    url = match.group(0)
+
+    return {"titles": TITLES_REGEX.findall(session.get(url).text)}
